==> green-core-1.76.1.tgz: package/components/card/card.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { css } from "lit";
import { tokens } from "../../tokens.style.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { GdsDiv } from "../div/div.component.js";
let GdsCard = class extends GdsDiv {
  /// This sets variables that are used in the default styles. Any other SEPs will override.
  constructor() {
    super();
    this.variant = "primary";
    this.padding = "s;m{l}";
    this["border-radius"] = "xs;m{s}";
    this["gap"] = "s;m{l}";
  }
  render() {
    return html`<slot></slot>`;
  }
};
GdsCard.styles = [
  tokens,
  css`
      :host {
        box-sizing: border-box;
        border-color: var(--_border-color);
        background-color: var(--_background-color);
        color: var(--_color);
        border-width: var(--gds-space-4xs);
        border-style: solid;
        display: flex;
        flex-direction: column;
      }
    `
];
__decorateClass([
  styleExpressionProperty({
    property: "box-shadow",
    valueTemplate: (v) => `var(--gds-shadow-${v})`
  })
], GdsCard.prototype, "shadow", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: function(_prop, v) {
      return `
      --_border-color: var(--gds-color-l${this.level}-background-${v});
      --_background-color: var(--gds-color-l${this.level}-background-${v});
      --_color: var(--gds-color-l${this.level}-content-${v});
      `;
    }
  })
], GdsCard.prototype, "variant", 2);
GdsCard = __decorateClass([
  gdsCustomElement("gds-card")
], GdsCard);
export {
  GdsCard
};

==> green-core-1.76.3.tgz: package/components/card/card.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { css } from "lit";
import { tokens } from "../../tokens.style.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { GdsDiv } from "../div/div.component.js";
let GdsCard = class extends GdsDiv {
  /// This sets variables that are used in the default styles. Any other SEPs will override.
  constructor() {
    super();
    this.variant = "primary";
    this.padding = "s;m{l}";
    this["border-radius"] = "xs;m{s}";
    this["gap"] = "s;m{l}";
  }
  render() {
    return html`<slot></slot>`;
  }
};
GdsCard.styles = [
  tokens,
  css`
      :host {
        box-sizing: border-box;
        border-color: var(--_border-color);
        background-color: var(--_background-color);
        color: var(--_color);
        border-width: var(--gds-sys-space-4xs);
        border-style: solid;
        display: flex;
        flex-direction: column;
      }
    `
];
__decorateClass([
  styleExpressionProperty({
    property: "box-shadow",
    valueTemplate: (v) => `var(--gds-shadow-${v})`
  })
], GdsCard.prototype, "shadow", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: function(_prop, v) {
      return `
      --_border-color: var(--gds-sys-color-l${this.level}-background-${v});
      --_background-color: var(--gds-sys-color-l${this.level}-background-${v});
      --_color: var(--gds-sys-color-l${this.level}-content-${v});
      `;
    }
  })
], GdsCard.prototype, "variant", 2);
GdsCard = __decorateClass([
  gdsCustomElement("gds-card")
], GdsCard);
export {
  GdsCard
};
